@@ -66,10 +66,10 @@ LogicalVector C_lowest(S4 las, List layout)
 }
 
 // [[Rcpp::export(rng = false)]]
-IntegerVector C_in_polygon(S4 las, CharacterVector wkts)
+SEXP C_in_polygon(S4 las, CharacterVector wkts, bool by_poly)
 {
   LAS pt(las);
-  return pt.find_polygon_ids(wkts);
+  return pt.find_polygon_ids(wkts, by_poly);
 }
 
 // [[Rcpp::export(rng = false)]]
@@ -211,11 +211,11 @@ int C_check_gpstime(NumericVector t, IntegerVector rn)
 }
 
 //[[Rcpp::export(rng = false)]]
-DataFrame C_eigen_metrics(S4 las, int k, double r, LogicalVector filter, int ncpu)
+DataFrame C_eigen_metrics(S4 las, int k, double r, bool coeffs, LogicalVector filter, int ncpu)
 {
   LAS pt(las, ncpu);
   pt.new_filter(filter);
-  return pt.eigen_decomposition(k, r);
+  return pt.eigen_decomposition(k, r, coeffs);
 }
 
 
